@@ -69,12 +69,6 @@ string ConnectionToBrowser::PrepareHeaderForServer()
         } else if ( it->find( "Keep-Alive", 0 ) == 0 )
         {
             continue;
-        } else if ( it->find( "Range:", 0 ) == 0 )
-        {
-            continue;
-        } else if ( it->find( "If-Range", 0 ) == 0 )
-	{
-            continue;
         } else if (( it->find( "Accept-Encoding", 0 ) && NOENCODING ) == 0 )
         {
             continue;
@@ -86,6 +80,17 @@ string ConnectionToBrowser::PrepareHeaderForServer()
             continue;
         }
 
+        if( Params::GetConfigBool("RANGE") == false )
+        {
+           if ( it->find( "Range:", 0 ) == 0 )
+           {
+             continue;
+           } else if ( it->find( "If-Range", 0 ) == 0 )
+	   {
+              continue;
+            }
+        }
+
         header += *it;
 
     }                                             //for
