@@ -34,6 +34,10 @@
 #include <stdarg.h>
 #include <stdio.h>
 
+#include <sys/socket.h>
+#include <netinet/in.h>
+#include <arpa/inet.h>
+
 using namespace std; 
 
 class ConnectionToBrowser : public HTTPHandler  {
@@ -42,6 +46,12 @@ private:
 
 map <string,string> URLRewrite;
 
+string Request;
+
+string Host;
+
+string IP;
+
 int Port;
 
 vector <string> Methods;
@@ -58,7 +68,10 @@ public:
 
 string PrepareHeaderForServer();
 
+string GetIP ();
+
 const char *GetHost();
+
 const string GetRequest();
 
 const char *GetCompleteRequest();
@@ -69,6 +82,8 @@ int GetPort();
 
 bool RewriteHost();
 
+void ClearVars();
+
 	ConnectionToBrowser();
 	~ConnectionToBrowser();
 };
