@@ -37,12 +37,11 @@ protected:
 
 string ScannerAnswer;
 
-pid_t ScannerPid;
-
 
 public:
 
-int msgqid;
+int commin[2];
+int commout[2];
 
 void WriteScannerAnswer ();
 
@@ -50,6 +49,10 @@ string ReadScannerAnswer ();
 
 bool PrepareScanning ( SocketHandler *ProxyServerT );
 
+bool CreatePipes ();
+
+virtual bool UnlockFile() = 0;
+
 virtual bool InitDatabase() = 0;
 
 virtual bool ReloadDatabase() = 0;
@@ -66,6 +69,8 @@ virtual bool ExpandFile( char *dataT, int lengthT , bool unlockT) = 0 ;
 
 virtual bool DeleteFile() = 0;
 
+virtual bool ReinitFile() = 0;
+
 //PSEstart
 virtual bool FreeDatabase() = 0;
 //PSEend
